Index: main/manager.c
===================================================================
--- main/manager.c	(revision 115414)
+++ main/manager.c	(working copy)
@@ -2983,6 +2983,58 @@
 		}
 	}
 
+	ast_config_destroy(cfg);
+	cfg = ast_config_load("users.conf");
+	
+	while ((cat = ast_category_browse(cfg, cat))) {
+		struct ast_variable *var = NULL;
+
+		if (!strcasecmp(cat, "general"))
+			continue;
+
+		/* Look for an existing entry, if none found - create one and add it to the list */
+		if (!(user = ast_get_manager_by_name_locked(cat))) {
+			if (!(user = ast_calloc(1, sizeof(*user))))
+				break;
+			/* Copy name over */
+			ast_copy_string(user->username, cat, sizeof(user->username));
+			/* Insert into list */
+			AST_LIST_INSERT_TAIL(&users, user, list);
+		}
+
+		/* Make sure we keep this user and don't destroy it during cleanup */
+		user->keep = 1;
+
+		var = ast_variable_browse(cfg, cat);
+		while (var) {
+			if (!strcasecmp(var->name, "secret")) {
+				if (user->secret)
+					free(user->secret);
+				user->secret = ast_strdup(var->value);
+			} else if (!strcasecmp(var->name, "deny") ) {
+				if (user->deny)
+					free(user->deny);
+				user->deny = ast_strdup(var->value);
+			} else if (!strcasecmp(var->name, "permit") ) {
+				if (user->permit)
+					free(user->permit);
+				user->permit = ast_strdup(var->value);
+			}  else if (!strcasecmp(var->name, "read") ) {
+				if (user->read)
+					free(user->read);
+				user->read = ast_strdup(var->value);
+			}  else if (!strcasecmp(var->name, "write") ) {
+				if (user->write)
+					free(user->write);
+				user->write = ast_strdup(var->value);
+			}  else if (!strcasecmp(var->name, "displayconnects") )
+				user->displayconnects = ast_true(var->value);
+			else
+				ast_log(LOG_DEBUG, "%s is an unknown option.\n", var->name);
+			var = var->next;
+		}
+	}
+
 	/* Perform cleanup - essentially prune out old users that no longer exist */
 	AST_LIST_TRAVERSE_SAFE_BEGIN(&users, user, list) {
 		if (user->keep) {
